%define module psycopg2

Summary:        PostgreSQL database adapter for Python
Name:           python-%module
Version:        2.5.1
Release:        %mkrel 3
Group:          Development/Python
License:        GPLv2 and ZPLv2.1 and BSD
URL:            http://www.initd.org/psycopg/
Source0:        http://initd.org/psycopg/tarballs/PSYCOPG-2-5/%{module}-%{version}.tar.gz
Source1:        http://initd.org/psycopg/tarballs/PSYCOPG-2-5/%{module}-%{version}.tar.gz.asc
BuildRequires:  pkgconfig(python)
BuildRequires:  python-setuptools
BuildRequires:  postgresql-devel
BuildRequires:  fdupes

%description
psycopg is a PostgreSQL database adapter for the Python programming
language (just like pygresql and popy.) It was written from scratch with
the aim of being very small and fast, and stable as a rock. The main
advantages of psycopg are that it supports the full Python DBAPI-2.0 and
being thread safe at level 2.

psycopg2 is an almost complete rewrite of the psycopg 1.1.x branch.

%package -n python3-%{module}
Summary:        PostgreSQL database adapter for Python 3
Group:          Development/Python
BuildRequires:  pkgconfig(python3)
BuildRequires:  python3-setuptools

%description -n python3-%{module}
psycopg is a PostgreSQL database adapter for the Python programming
language (just like pygresql and popy.) It was written from scratch with
the aim of being very small and fast, and stable as a rock. The main
advantages of psycopg are that it supports the full Python DBAPI-2.0 and
being thread safe at level 2.

%package doc
Summary:        Documentation for psycopg python PostgreSQL database adapter
Group:          Development/Python
BuildArch:      noarch
Requires:       %{name} = %{version}-%{release}

%description doc
Documentation and example files for the psycopg python PostgreSQL
database adapter.

%prep
%setup -q -n %{module}-%{version}
cp -a . %{py3dir} 

%build
export CFLAGS="%{optflags}"
%{__python} setup.py build

pushd %{py3dir} 
%{__python3} setup.py build
popd

# Fix for wrong-file-end-of-line-encoding problem; upstream also must fix this.
for i in `find doc -iname "*.html"`; do sed -i 's/\r//' $i; done
for i in `find doc -iname "*.css"`; do sed -i 's/\r//' $i; done

# Get rid of a "hidden" file that rpmlint complains about
rm -f doc/html/.buildinfo

%install
pushd %{py3dir}
%{__python3} setup.py install --skip-build --root %{buildroot}
popd

%{__python} setup.py install --skip-build --root=%{buildroot}

rm -rf $RPM_BUILD_ROOT%{python_sitearch}/psycopg2/tests
rm -rf $RPM_BUILD_ROOT%{python3_sitearch}/psycopg2/tests

%fdupes $RPM_BUILD_ROOT%{python_sitearch}
%fdupes $RPM_BUILD_ROOT%{python3_sitearch}

%files
%doc AUTHORS LICENSE NEWS README
%{python_sitearch}/psycopg2*

%files -n python3-%{module}
%doc AUTHORS LICENSE NEWS README
%{python3_sitearch}/psycopg2*

%files doc
%doc doc examples/


%changelog
* Tue Oct 22 2013 umeabot <umeabot> 2.5.1-3.mga4
+ Revision: 544096
- Mageia 4 Mass Rebuild

* Tue Oct 15 2013 pterjan <pterjan> 2.5.1-2.mga4
+ Revision: 499129
- Rebuild to add different pythonegg provides for python 2 and 3

* Mon Aug 05 2013 philippem <philippem> 2.5.1-1.mga4
+ Revision: 464016
- Update to 2.5.1, add Python 3

* Sun Jan 13 2013 umeabot <umeabot> 2.4.6-2.mga3
+ Revision: 379288
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sun Dec 23 2012 philippem <philippem> 2.4.6-1.mga3
+ Revision: 334288
- Update to 2.4.6

* Wed Feb 15 2012 philippem <philippem> 2.4.4-1.mga2
+ Revision: 209267
- Update to 2.4.4.

* Mon Jul 04 2011 ahmad <ahmad> 2.4.2-1.mga2
+ Revision: 118081
- Update to 2.4.2
- Update URL and Source urls
- Rediff patch0

* Sat Mar 26 2011 dmorgan <dmorgan> 2.3.2-1.mga1
+ Revision: 77549
- imported package python-psycopg2


* Tue Dec 28 2010 Guillaume Rousse <guillomovitch@mandriva.org> 2.3.2-1mdv2011.0
+ Revision: 625615
- update to new version 2.3.2

* Tue Nov 30 2010 Funda Wang <fwang@mandriva.org> 2.2.2-1mdv2011.0
+ Revision: 603245
- fix linkage

  + Guillaume Rousse <guillomovitch@mandriva.org>
    - update to new version 2.2.2

* Wed Nov 03 2010 Götz Waschk <waschk@mandriva.org> 2.0.13-3mdv2011.0
+ Revision: 592882
- fix file list

  + Michael Scherer <misc@mandriva.org>
    - rebuild for python 2.7

* Sat Nov 07 2009 Frederik Himpe <fhimpe@mandriva.org> 2.0.13-1mdv2010.1
+ Revision: 462522
- update to new version 2.0.13

* Sun Aug 09 2009 Frederik Himpe <fhimpe@mandriva.org> 2.0.12-1mdv2010.0
+ Revision: 413417
- update to new version 2.0.12

* Mon May 18 2009 Frederik Himpe <fhimpe@mandriva.org> 2.0.11-1mdv2010.0
+ Revision: 377268
- Update to new version 2.0.11

* Thu Mar 05 2009 Frederik Himpe <fhimpe@mandriva.org> 2.0.9-1mdv2009.1
+ Revision: 349096
- Update to new version 2.0.9

* Sun Jan 04 2009 Jérôme Soyer <saispo@mandriva.org> 2.0.8-1mdv2009.1
+ Revision: 324057
- New upstream release

* Fri Aug 08 2008 Thierry Vignaud <tv@mandriva.org> 2.0.7-2mdv2009.0
+ Revision: 269038
- rebuild early 2009.0 package (before pixel changes)

* Sun May 04 2008 Frederik Himpe <fhimpe@mandriva.org> 2.0.7-1mdv2009.0
+ Revision: 200808
- New upstream version

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

  + Thierry Vignaud <tv@mandriva.org>
    - kill re-definition of %%buildroot on Pixel's request

* Tue Jul 17 2007 Bogdano Arendartchuk <bogdano@mandriva.com> 2.0.6-1mdv2008.0
+ Revision: 53010
- Import python-psycopg2

